[libvirt] [PATCH] qemu: fix typo in name - should be VHOST_NET, not VNET_HOST

Laine Stump laine at laine.org
Mon May 23 17:43:18 UTC 2011


---
 configure.ac                 |    8 +++++---
 src/qemu/qemu_capabilities.c |    2 +-
 src/qemu/qemu_capabilities.h |    2 +-
 src/qemu/qemu_command.c      |    2 +-
 tests/qemuhelptest.c         |    8 ++++----
 5 files changed, 12 insertions(+), 10 deletions(-)

diff --git a/configure.ac b/configure.ac
index 80a13a1..b6f433b 100644
--- a/configure.ac
+++ b/configure.ac
@@ -318,14 +318,16 @@ AC_ARG_WITH([init-script],
             [AC_HELP_STRING([--with-init-script=@<:@redhat|auto|none@:>@],
 		     [Style of init script to install @<:@default=auto@:>@])])
 if test "x$with_init_script" = "x" || test "x$with_init_script" = "xauto"; then
-    if test "$cross_compiling" = yes || test ! -f /etc/redhat-release; then
+    if test "$sysconfdir" != "/etc" || test "$cross_compiling" = yes \
+       || test ! -f /etc/redhat-release; then
         with_init_script=none
     else
         with_init_script=redhat
     fi
 fi
-AM_CONDITIONAL([LIBVIRT_INIT_SCRIPT_RED_HAT], test x$with_init_script = xredhat)
-AC_MSG_RESULT($with_init_script)
+AM_CONDITIONAL([LIBVIRT_INIT_SCRIPT_RED_HAT],
+               [test x$with_init_script = xredhat])
+AC_MSG_RESULT([$with_init_script])
 
 dnl RHEL-5 has a peculiar version of Xen, which requires some special casing
 AC_ARG_WITH([rhel5-api],
diff --git a/src/qemu/qemu_capabilities.c b/src/qemu/qemu_capabilities.c
index 71a54a5..8289141 100644
--- a/src/qemu/qemu_capabilities.c
+++ b/src/qemu/qemu_capabilities.c
@@ -983,7 +983,7 @@ qemuCapsComputeCmdFlags(const char *help,
         qemuCapsSet(flags, QEMU_CAPS_VNET_HDR);
 
     if (strstr(help, ",vhost=")) {
-        qemuCapsSet(flags, QEMU_CAPS_VNET_HOST);
+        qemuCapsSet(flags, QEMU_CAPS_VHOST_NET);
     }
 
     /*
diff --git a/src/qemu/qemu_command.c b/src/qemu/qemu_command.c
index 2828823..a4a7e8e 100644
--- a/src/qemu/qemu_command.c
+++ b/src/qemu/qemu_command.c
@@ -320,7 +320,7 @@ qemuOpenVhostNet(virDomainDefPtr def,
     /* If qemu doesn't support vhost-net mode (including the -netdev command
      * option), don't try to open the device.
      */
-    if (!(qemuCapsGet(qemuCaps, QEMU_CAPS_VNET_HOST) &&
+    if (!(qemuCapsGet(qemuCaps, QEMU_CAPS_VHOST_NET) &&
           qemuCapsGet(qemuCaps, QEMU_CAPS_NETDEV) &&
           qemuCapsGet(qemuCaps, QEMU_CAPS_DEVICE))) {
         if (net->driver.virtio.name == VIR_DOMAIN_NET_BACKEND_TYPE_VHOST) {
diff --git a/tests/qemuhelptest.c b/tests/qemuhelptest.c
index 2522396..71780d8 100644
--- a/tests/qemuhelptest.c
+++ b/tests/qemuhelptest.c
@@ -333,7 +333,7 @@ mymain(void)
             QEMU_CAPS_DEVICE,
             QEMU_CAPS_SMP_TOPOLOGY,
             QEMU_CAPS_RTC,
-            QEMU_CAPS_VNET_HOST,
+            QEMU_CAPS_VHOST_NET,
             QEMU_CAPS_NO_KVM_PIT,
             QEMU_CAPS_TDF,
             QEMU_CAPS_PCI_CONFIGFD,
@@ -374,7 +374,7 @@ mymain(void)
             QEMU_CAPS_DEVICE,
             QEMU_CAPS_SMP_TOPOLOGY,
             QEMU_CAPS_RTC,
-            QEMU_CAPS_VNET_HOST,
+            QEMU_CAPS_VHOST_NET,
             QEMU_CAPS_NO_HPET,
             QEMU_CAPS_NO_KVM_PIT,
             QEMU_CAPS_TDF,
@@ -415,7 +415,7 @@ mymain(void)
             QEMU_CAPS_SMP_TOPOLOGY,
             QEMU_CAPS_NETDEV,
             QEMU_CAPS_RTC,
-            QEMU_CAPS_VNET_HOST,
+            QEMU_CAPS_VHOST_NET,
             QEMU_CAPS_NO_HPET,
             QEMU_CAPS_NO_KVM_PIT,
             QEMU_CAPS_TDF,
@@ -456,7 +456,7 @@ mymain(void)
             QEMU_CAPS_DEVICE,
             QEMU_CAPS_SMP_TOPOLOGY,
             QEMU_CAPS_RTC,
-            QEMU_CAPS_VNET_HOST,
+            QEMU_CAPS_VHOST_NET,
             QEMU_CAPS_NO_KVM_PIT,
             QEMU_CAPS_TDF,
             QEMU_CAPS_PCI_CONFIGFD,
diff --git a/src/qemu/qemu_capabilities.h b/src/qemu/qemu_capabilities.h
index ab47f22..4c1ad63 100644
--- a/src/qemu/qemu_capabilities.h
+++ b/src/qemu/qemu_capabilities.h
@@ -66,7 +66,7 @@ enum qemuCapsFlags {
     QEMU_CAPS_SMP_TOPOLOGY      = 28, /* Is sockets=s,cores=c,threads=t available for -smp? */
     QEMU_CAPS_NETDEV            = 29, /* The -netdev flag & netdev_add/remove monitor commands */
     QEMU_CAPS_RTC               = 30, /* The -rtc flag for clock options */
-    QEMU_CAPS_VNET_HOST         = 31, /* vnet-host support is available in qemu */
+    QEMU_CAPS_VHOST_NET         = 31, /* vhost-net support is available in qemu */
     QEMU_CAPS_RTC_TD_HACK       = 32, /* -rtc-td-hack available */
     QEMU_CAPS_NO_HPET           = 33, /* -no-hpet flag is supported */
     QEMU_CAPS_NO_KVM_PIT        = 34, /* -no-kvm-pit-reinjection supported */
-- 
1.7.3.4




More information about the libvir-list mailing list